
*PLANFOR*

egen turma100 = group (turma)
tab turma100 , generate (strata)
gen T = trat


*Pscore*
logit T strata*
predict pscore
egen p = mean(T)
gen w01 =  ((1-T)/(1-pscore))*(pscore/p)
egen sw01 = sum(w01)
replace w01 =  w01/sw01

gen w11 = T/p
egen sw11= sum(w11)
replace w11 = w11/sw11
 
gen w00 = (1-T)/(1-p)
egen sw00= sum(w00)
replace w00 = w00/sw00


** Gini **
 
 
program define ginicoef, rclass
    version 5.0
    quietly
   {
     gsort `1'
              tempvar a2
              tempname cum_wt cumwy glp pvar rfvar rf ginicoef
              quietly summarize `1' [aweight=`2']
              tempname tot_wt mean twovm
              scalar `tot_wt'=_result(2)
              scalar `mean'=_result(3)
              scalar `twovm'=2/`mean'
              quietly generate `cum_wt'=sum(`2')
              quietly gen double `cumwy' = sum(`1'*`2')
              quietly gen double `glp'=`cumwy'/`tot_wt'
              quietly gen double `pvar' = `cum_wt'/`tot_wt'
              quietly integ `glp' `pvar', gen(`rfvar')
              scalar `rf'=`rfvar'[_N]
              matrix define `a2'=`twovm'*`rf'
              matrix define ginicoef =1-`a2'
                  svmat ginicoef
                  matrix drop ginicoef `a2'
                  return scalar gini = ginicoef1
                  drop ginicoef1
    }
 end

 
 
 
program define ite_planfor, rclass
 
args y
 
 
quietly
{
 
 
***Feasible - Firpo ***
 
 
tempvar p pscore_parametrico w11 w00 sw00 sw01_par w01_par sw11 w1_par sw1_par
tempvar w0_par sw0_par
egen `p'  = mean(T)
logit T strata*  
predict `pscore_parametrico'

sum `pscore_parametrico'
return scalar pscore_medio = r(mean)
return scalar pscore_min = r(min)
return scalar pscore_max = r(max)

sum `pscore_parametrico' if T==1
return scalar pscore_medio_trat = r(mean)
return scalar pscore_min_trat = r(min)
return scalar pscore_max_trat = r(max)

sum `pscore_parametrico' if T==0
return scalar pscore_medio_control = r(mean)
return scalar pscore_min_control = r(min)
return scalar pscore_max_control = r(max)

 

gen `w11' = T/`p'
egen `sw11'= sum(`w11')
replace `w11' = `w11'/`sw11'
 
gen `w00' = (1-T)/(1-`p')
egen `sw00'= sum(`w00')
replace `w00' = `w00'/`sw00'
 
 
gen `w01_par' =  ((1-T)/(1-`pscore_parametrico'))*(`pscore_parametrico'/`p')
egen `sw01_par' = sum(`w01_par')
replace `w01_par' =  `w01_par'/`sw01_par'
 
 
gen `w1_par' =  (T/`pscore_parametrico')
egen `sw1_par' = sum(`w1_par')
replace `w1_par' =  `w1_par'/`sw1_par'

gen `w0_par' =  ((1-T)/(1-`pscore_parametrico'))
egen `sw0_par' = sum(`w0_par')
replace `w0_par' = `w0_par'/`sw0_par'
 
 
**********************************************************************************
*** Counterfactual : Juhn, Murphy and Pierce ***
 
tempvar xtbetac sigma_c sigma_t sigmac2 y01_jmp erro_t lny stbetac2 sigma_c2 sigma_t2  erro_t2 lny_01jmp y01_ln_jmp xtbetac2 xtbetac3 sigma_c3 erro_t3 sigma_t3 lny_01jmp_q y01_ln_jmp_q
 
*** Counterfactual : Juhn, Murphy and Pierce *** (quadratico em X, variavel dep: y)
 
 
reg `y' strata*   if T==0 
predict `xtbetac' if T==1 

 
gen `sigma_c' = e(rss)/e(df_r)
 
reg `y' strata* if T==1
predict `erro_t' , residuals 
gen `sigma_t' = e(rss)/e(df_r)
 
 
gen `y01_jmp' = `xtbetac' + sqrt(`sigma_c'/`sigma_t')*`erro_t' 

tempvar xtbetac1 sigma_c_1 erro_to sigma_to y1_jmp xtbetac0 sigma_c_0 y0_jmp termc1 termc0

reg `y' strata*  if T==1
predict `xtbetac1' 
 
gen `sigma_c_1' = e(rss)/e(df_r)
 
reg `y' strata* 
predict `erro_to' , residuals 
gen `sigma_to' = e(rss)/e(df_r)

gen  `termc1' = sqrt(`sigma_c_1'/`sigma_to')*`erro_to'
gen `y1_jmp' = `xtbetac1' +  `termc1'   


reg `y' strata*  if T==0
predict `xtbetac0' 
 
gen `sigma_c_0' = e(rss)/e(df_r) 

gen  `termc0' = sqrt(`sigma_c_0'/`sigma_to')*`erro_to' 
gen `y0_jmp' = `xtbetac0' +  `termc0'

 
*** Counterfactual : Juhn, Murphy and Pierce *** (quadratico em X, variavel dep: ln(y)) 
 
gen `lny' = log(`y')
 
reg `lny' strata* if T==0
predict `xtbetac2' if T==1
 
gen `sigma_c2' = e(rss)/e(df_r)
 
reg `lny' strata*  if T==1
predict `erro_t2' , residuals 
gen `sigma_t2' = e(rss)/e(df_r)
 
gen `lny_01jmp' = `xtbetac2' + sqrt(`sigma_c2'/`sigma_t2')*`erro_t2' 
gen `y01_ln_jmp' = exp(`lny_01jmp') 
 

tempvar  xtbetac21 sigma_c21 xtbetac20 sigma_c20 erro_t20  sigma_t20 lny_1jmp y1_ln_jmp lny_0jmp y0_ln_jmp
 
reg `lny' strata* if T==1
predict `xtbetac21' 
 
gen `sigma_c21' = e(rss)/e(df_r)
 
reg `lny' strata* if T==0
predict `xtbetac20' 
 
gen `sigma_c20' = e(rss)/e(df_r)
 
reg `lny' strata* 
predict `erro_t20' , residuals 
gen `sigma_t20' = e(rss)/e(df_r)

gen `lny_1jmp' = `xtbetac21' + sqrt(`sigma_c21'/`sigma_t20')*`erro_t20' 
gen `y1_ln_jmp' = exp(`lny_1jmp')  

 
gen `lny_0jmp' = `xtbetac20' + sqrt(`sigma_c20'/`sigma_t20')*`erro_t20' 
gen `y0_ln_jmp' = exp(`lny_0jmp')
  
************************************************************************************
 
 
 
************************************************************************************
 
 
 
* Gerando as estatisticas de interesse *
 

*Average*
 
tempvar my1 my0  my_t my_c my01_feasible my01_jmp my01_ln_jmp my01_ln_jmp_q
 
 
 
* Naive *
 
reg `y' [w=`w11']
gen `my_t' = _b[_cons]
return scalar my_t = `my_t'
reg `y' [w=`w00']
gen `my_c' = _b[_cons]
return scalar my_c = `my_c'
tempvar att_naive
gen `att_naive' = `my_t' - `my_c'
return scalar att_naive = `att_naive'
 
tempvar my_to my_co 
reg `y' [w=`w11']
gen `my_to' = _b[_cons]
return scalar my_to = `my_to'
reg `y'[w=`w00']
gen `my_co' = _b[_cons]
return scalar my_co = `my_co'
tempvar ate_naive 
gen `ate_naive' = `my_to' - `my_co'
return scalar ate_naive = `ate_naive' 
 
*Firpo*
 
tempvar att_feasible
reg `y' [w=`w01_par']
gen `my01_feasible' = _b[_cons]
gen `att_feasible' = `my_t' - `my01_feasible'
return scalar att_feasible = `att_feasible'


tempvar ate_feasible my1_feasible  my0_feasible
reg `y' [w=`w1_par']
gen `my1_feasible' = _b[_cons]
reg `y' [w=`w0_par']
gen `my0_feasible' = _b[_cons]
gen `ate_feasible' = `my1_feasible' - `my0_feasible'
return scalar ate_feasible = `ate_feasible'
 
*JMP_y*
egen `my01_jmp' = mean(`y01_jmp')
tempvar att_jmp
gen `att_jmp' = `my_t' -  `my01_jmp'
return scalar att_jmp = `att_jmp'
 
tempvar my1_jmp my0_jmp
egen `my1_jmp' = mean(`y1_jmp')
egen `my0_jmp' = mean(`y0_jmp')
tempvar ate_jmp 
gen `ate_jmp' = `my1_jmp' -  `my0_jmp'
return scalar ate_jmp = `ate_jmp' 
 
*JMP_lny*
egen `my01_ln_jmp' = mean(`y01_ln_jmp')
tempvar att_ln_jmp
gen `att_ln_jmp' = `my_t' - `my01_ln_jmp'
return scalar att_ln_jmp  = `att_ln_jmp'
 
tempvar my1_ln_jmp my0_ln_jmp
egen `my1_ln_jmp' = mean(`y1_ln_jmp') 
egen `my0_ln_jmp' = mean(`y0_ln_jmp')
tempvar ate_ln_jmp 
gen `ate_ln_jmp' = `my1_ln_jmp' - `my0_ln_jmp'
return scalar ate_ln_jmp  = `ate_ln_jmp'
 
 
 
*Coeficiente de Variacao *
 
tempvar sdy1 sdy0 sdy_t sdy_c sdy01_feasible sdy01_jmp sdy01_ln_jmp sdy01_ln_jmp_q
 
 
 
*Naive*
 
sum `y' [w=`w11']
gen  `sdy_t' = r(sd)
sum `y' [w=`w00']
gen `sdy_c' = r(sd)
tempvar CV_t CV_c
gen  `CV_t' = `sdy_t'/`my_t'
gen  `CV_c' = `sdy_c'/`my_c'
return scalar CV_t = `CV_t'
return scalar CV_c = `CV_c'
tempvar CV_naive
gen `CV_naive'  = `sdy_t'/`my_t' - `sdy_c'/`my_c'
return scalar CV_naive = `CV_naive'
 
tempvar  sdy_to sdy_co
sum `y' [w=`w11']
gen  `sdy_to' = r(sd)
sum `y' [w=`w00']
gen `sdy_co' = r(sd)
tempvar CV_naiveo CV_to CV_co 
gen `CV_naiveo'  = `sdy_to'/`my_to' - `sdy_co'/`my_co'
gen  `CV_to' = `sdy_to'/`my_to'
gen  `CV_co' = `sdy_co'/`my_co'
return scalar CV_to = `CV_to'
return scalar CV_co = `CV_co'
return scalar CV_naiveo = `CV_naiveo' 
 
*Feasible-Firpo*
 
summ `y'[w=`w01_par']
gen `sdy01_feasible' = r(sd)
tempvar CV_feasible
gen `CV_feasible' = `sdy_t'/`my_t'  -  `sdy01_feasible'/`my01_feasible'
return scalar CV_feasible  = `CV_feasible'

tempvar  sdy0_feasible sdy1_feasible
summ `y' [w=`w0_par']
gen `sdy0_feasible' = r(sd)
summ `y' [w=`w1_par']
gen `sdy1_feasible' = r(sd)
tempvar CV_feasibleo
gen `CV_feasibleo' = `sdy1_feasible'/`my1_feasible'  -  `sdy0_feasible'/`my0_feasible'
return scalar CV_feasibleo  = `CV_feasibleo'

 
*JMP*
 
egen `sdy01_jmp' = sd(`y01_jmp')
tempvar CV_jmp
gen `CV_jmp' = `sdy_t'/`my_t' - `sdy01_jmp'/`my01_jmp'
return scalar CV_jmp = `CV_jmp'

tempvar sdy1_jmp sdy0_jmp
egen `sdy1_jmp' = sd(`y1_jmp') 
egen `sdy0_jmp' = sd(`y0_jmp')
tempvar CV_jmpo
gen `CV_jmpo' = `sdy1_jmp'/`my1_jmp' - `sdy0_jmp'/`my0_jmp'
return scalar CV_jmpo = `CV_jmpo' 
 
* JMP_lny*
 
egen `sdy01_ln_jmp' = sd(`y01_ln_jmp')
tempvar CV_ln_jmp
gen `CV_ln_jmp' = `sdy_t'/`my_t' - `sdy01_ln_jmp'/`my01_ln_jmp'
return scalar CV_ln_jmp = `CV_ln_jmp'
 
tempvar sdy1_ln_jmp sdy0_ln_jmp
egen `sdy1_ln_jmp' = sd(`y1_ln_jmp') 
egen `sdy0_ln_jmp' = sd(`y0_ln_jmp')
tempvar CV_ln_jmpo
gen `CV_ln_jmpo' = `sdy1_ln_jmp'/`my1_ln_jmp' - `sdy0_ln_jmp'/`my0_ln_jmp'
return scalar CV_ln_jmpo = `CV_ln_jmpo'


  
 
 
 
*Interquartile Range *
 
 
tempvar y1_q75 y1_q25 y0_q75 y0_q25 yt_q75 yt_q25 yc_q75 yc_q25
tempvar  y01_q75feasible  y01_q25feasible y01_q75jmp y01_q25jmp  y01_q75_ln_jmp y01_q25_ln_jmp  y01_q75_ln_jmp_q y01_q25_ln_jmp_q

 
* Naive *
tempvar w11a w00a
gen `w11a'=round(`w11'*1000000)
gen `w00a'=round(`w00'*1000000)
quietly qreg `y'[w=`w11a'] , quantile (.75) 
gen `yt_q75' = e(q_v)
quietly qreg `y'[w=`w11a'] , quantile (.25) 
gen `yt_q25' = e(q_v)
tempvar iqr_t iqr_c
gen `iqr_t'  = (`yt_q75' - `yt_q25' )
return scalar iqr_t  =`iqr_t'
quietly qreg `y'[w=`w00a'] , quantile (.75) 
gen `yc_q75' = e(q_v)
quietly qreg `y'[w=`w00a'] , quantile (.25) 
gen `yc_q25' = e(q_v)
gen `iqr_c'  = (`yc_q75' - `yc_q25' )
return scalar iqr_c  =`iqr_c'  
tempvar iqr_naive
gen `iqr_naive' = (`yt_q75' - `yt_q25' ) - (`yc_q75' - `yc_q25' )
return scalar iqr_naive = `iqr_naive'



* Feasible-Firpo *
tempvar w01_para
gen `w01_para'=round(`w01_par'*1000000)
quietly qreg `y'[w=`w01_para'] , quantile (.75) 
gen `y01_q75feasible' = e(q_v)
quietly qreg `y'[w=`w01_para'], quantile (.25) 
gen `y01_q25feasible' = e(q_v)
tempvar iqr_feasible
gen  `iqr_feasible' = (`yt_q75' - `yt_q25' ) - (`y01_q75feasible' - `y01_q25feasible')
return scalar iqr_feasible  = `iqr_feasible'

tempvar w1_para w0_para y1_q75feasible y1_q25feasible y0_q75feasible y0_q25feasible
gen `w1_para'=round(`w1_par'*1000000)
quietly qreg `y' [w=`w1_para'] , quantile (.75)
gen `y1_q75feasible' = e(q_v)
quietly qreg `y' [w=`w1_para'], quantile (.25)
gen `y1_q25feasible' = e(q_v)
gen `w0_para'=round(`w0_par'*1000000)
quietly qreg `y' [w=`w0_para'] , quantile (.75)
gen `y0_q75feasible' = e(q_v)
quietly qreg `y' [w=`w0_para'], quantile (.25)
gen `y0_q25feasible' = e(q_v)
tempvar iqr_feasibleo
gen  `iqr_feasibleo' = (`y1_q75feasible' - `y1_q25feasible') - (`y0_q75feasible' - `y0_q25feasible')
return scalar iqr_feasibleo  = `iqr_feasibleo'

 
* JMP *
 
quietly qreg `y01_jmp' , quantile(.75) 
gen `y01_q75jmp' = e(q_v)
quietly qreg `y01_jmp', quantile (.25) 
gen `y01_q25jmp' = e(q_v)
tempvar iqr_jmp
gen `iqr_jmp' = ( `yt_q75' - `yt_q25') - (`y01_q75jmp' - `y01_q25jmp')
return scalar iqr_jmp = `iqr_jmp'

tempvar y1_q75jmp y0_q75jmp y1_q25jmp y0_q25jmp
quietly qreg `y1_jmp' , quantile(.75)
gen `y1_q75jmp' = e(q_v)
quietly qreg `y1_jmp', quantile (.25)
gen `y1_q25jmp' = e(q_v)
quietly qreg `y0_jmp' , quantile(.75)
gen `y0_q75jmp' = e(q_v)
quietly qreg `y0_jmp', quantile (.25)
gen `y0_q25jmp' = e(q_v)
tempvar iqr_jmpo
gen `iqr_jmpo' = (`y1_q75jmp' - `y1_q25jmp') - (`y0_q75jmp' - `y0_q25jmp')
return scalar iqr_jmpo = `iqr_jmpo' 

 
*JMP_lny *
 
quietly qreg `y01_ln_jmp' , quantile (.75) 
gen `y01_q75_ln_jmp' = e(q_v)
quietly qreg `y01_ln_jmp' , quantile (.25) 
gen `y01_q25_ln_jmp' = e(q_v)
tempvar iqr_ln_jmp
gen `iqr_ln_jmp'= (`yt_q75' - `yt_q25') - (`y01_q75_ln_jmp' - `y01_q25_ln_jmp')
return scalar iqr_ln_jmp = `iqr_ln_jmp'
 
tempvar  y0_q75_ln_jmp y1_q75_ln_jmp y0_q25_ln_jmp y1_q25_ln_jmp
quietly qreg `y1_ln_jmp' , quantile (.75)
gen `y1_q75_ln_jmp' = e(q_v)
quietly qreg `y1_ln_jmp' , quantile (.25)
gen `y1_q25_ln_jmp' = e(q_v)
quietly qreg `y0_ln_jmp' , quantile (.75)
gen `y0_q75_ln_jmp' = e(q_v)
quietly qreg `y0_ln_jmp' , quantile (.25)
gen `y0_q25_ln_jmp' = e(q_v)
tempvar iqr_ln_jmpo
gen `iqr_ln_jmpo'= (`y1_q75_ln_jmp' - `y1_q25_ln_jmp') - (`y0_q75_ln_jmp' - `y0_q25_ln_jmp')
return scalar iqr_ln_jmpo = `iqr_ln_jmpo'  
 
*Gini* 
tempvar gini_y1 gini_y0  gini_t gini_c gini_y01feasible
 
**Naive **
ginicoef `y' `w11'
gen `gini_t' = r(gini)
ginicoef `y' `w00'
gen `gini_c' = r(gini)
return scalar gini_t = `gini_t'
return scalar gini_c = `gini_c'
tempvar gini_naive
gen `gini_naive' =  `gini_t' - `gini_c'

return scalar gini_naive = `gini_naive'

 
* Feasible - Firpo *
 
ginicoef `y' `w01_par'
gen `gini_y01feasible' = r(gini)
tempvar gini_feasible
gen `gini_feasible' = `gini_t' - `gini_y01feasible'
return scalar gini_feasible = `gini_feasible'

tempvar gini_y1feasible gini_y0feasible 
ginicoef `y' `w1_par'
gen `gini_y1feasible' = r(gini)
ginicoef `y' `w0_par'
gen `gini_y0feasible' = r(gini)
tempvar gini_feasibleo
gen `gini_feasibleo' = `gini_y1feasible' - `gini_y0feasible'
return scalar gini_feasible = `gini_feasibleo'

 
* JMP *
tempvar gini_y01jmp gini_y01_ln_jmp  y01_jmp_positive
gen `y01_jmp_positive' = `y01_jmp' if `y01_jmp'>0
ginicoef `y01_jmp_positive' `w11'
gen `gini_y01jmp' = r(gini)
tempvar gini_jmp
gen `gini_jmp' = `gini_t' -  `gini_y01jmp'
return scalar gini_jmp = `gini_jmp'


tempvar y1_jmp_positive y0_jmp_positive total_negative1 total_negative0
gen `y1_jmp_positive' = `y1_jmp' if `y1_jmp'>0
gen `total_negative1' = missing(`y1_jmp_positive')
replace `total_negative1' =sum(`total_negative1')
return scalar total_negative1 = `total_negative1'

gen `y0_jmp_positive' = `y0_jmp' if `y0_jmp'>0
gen `total_negative0' = missing(`y0_jmp_positive')
replace `total_negative0' =sum(`total_negative0')
return scalar total_negative0 = `total_negative0'

tempvar gini_y1jmp gini_y0jmp wg
gen  `wg'=1
ginicoef `y1_jmp_positive'  `wg'
gen `gini_y1jmp' = r(gini)
ginicoef `y0_jmp_positive' `wg'
gen `gini_y0jmp' = r(gini)
tempvar gini_jmpo 
gen `gini_jmpo' = `gini_y1jmp' -  `gini_y0jmp'
return scalar gini_jmpo = `gini_jmpo'
 
*JMP_lny*
 
ginicoef `y01_ln_jmp'  `w11'
gen `gini_y01_ln_jmp' = r(gini)
tempvar gini_ln_jmp
gen `gini_ln_jmp'  = `gini_t' - `gini_y01_ln_jmp'
return scalar gini_ln_jmp = `gini_ln_jmp'
tempvar  gini_y1_ln_jmp gini_y0_ln_jmp
ginicoef `y1_ln_jmp'  `wg'
gen `gini_y1_ln_jmp' = r(gini)
ginicoef `y0_ln_jmp'  `wg'
gen `gini_y0_ln_jmp' = r(gini)
tempvar gini_ln_jmpo  
gen `gini_ln_jmpo'  = `gini_y1_ln_jmp' - `gini_y0_ln_jmp'
return scalar gini_ln_jmpo = `gini_ln_jmpo'


 
 
*Theil Index *
tempvar th_y1 th_y0 th_yt th_yc th_y01feasible th_y01jmp ty_y01_ln_jmp 
tempvar theil_y1 theil_yt theil_y0 theil_yc theil_y01feasible
 
 
 
*Naive*
gen `th_yt' = (`y'/`my_t')*log(`y'/`my_t')
reg `th_yt'  [w=`w11']
gen `theil_yt' = _b[_cons]
gen `th_yc' = (`y'/`my_c')*log(`y'/`my_c')
reg `th_yc'  [w=`w00']
gen `theil_yc' = _b[_cons]
tempvar theil_naive 
return scalar theil_yt = `theil_yt'
return scalar theil_yc = `theil_yc'

gen `theil_naive' = `theil_yt' - `theil_yc'
return scalar theil_naive = `theil_naive'
 
 
*Firpo-Feasible *
tempvar theil_feasible th_y01jmp th_y01_ln_jmp theil_y01jmp theil_ln_jmp theil_y01_ln_jmp
 
 
gen `th_y01feasible' = (`y'/`my01_feasible')*(log(`y'/`my01_feasible'))
reg `th_y01feasible'  [w=`w01_par']
gen `theil_y01feasible' = _b[_cons]
gen `theil_feasible' = `theil_yt' - `theil_y01feasible'
return scalar theil_feasible = `theil_feasible'


tempvar theil_feasibleo th_y0feasible theil_y0feasible th_y1feasible theil_y1feasible
gen `th_y0feasible' = (`y'/`my0_feasible' )*(log(`y'/`my0_feasible'))
reg `th_y0feasible'  [w=`w0_par']
gen `theil_y0feasible' = _b[_cons]

gen `th_y1feasible' = (`y'/`my1_feasible' )*(log(`y'/`my1_feasible'))
reg `th_y1feasible'  [w=`w1_par']
gen `theil_y1feasible' = _b[_cons]
gen `theil_feasibleo' = `theil_y1feasible' - `theil_y0feasible'
return scalar theil_feasibleo = `theil_feasibleo'
 
*Jmp *
 
tempvar my01_jmp_positive
egen `my01_jmp_positive' = mean(`y01_jmp_positive')
gen `th_y01jmp' = (`y01_jmp_positive'/`my01_jmp_positive')*log(`y01_jmp_positive'/`my01_jmp_positive')
reg `th_y01jmp'
gen `theil_y01jmp'= _b[_cons]
tempvar theil_jmp
gen `theil_jmp' = `theil_yt' - `theil_y01jmp'
return scalar theil_jmp = `theil_jmp'

tempvar my1_jmp_positive th_y1jmp theil_y1jmp th_y1_ln_jmp theil_y1_ln_jmp my0_jmp_positive th_y0jmp theil_y0jmp th_y0_ln_jmp theil_y0_ln_jmp 
egen `my0_jmp_positive' = mean(`y0_jmp_positive')
gen `th_y0jmp' = (`y0_jmp_positive'/`my0_jmp_positive')*log(`y0_jmp_positive'/`my0_jmp_positive')
reg `th_y0jmp'
gen `theil_y0jmp'= _b[_cons]
egen `my1_jmp_positive' = mean(`y1_jmp_positive')
gen `th_y1jmp' = (`y1_jmp_positive'/`my1_jmp_positive')*log(`y1_jmp_positive'/`my1_jmp_positive')
reg `th_y1jmp'
gen `theil_y1jmp'= _b[_cons]
tempvar theil_jmpo
gen `theil_jmpo' = `theil_y1jmp' - `theil_y0jmp'
return scalar theil_jmpo = `theil_jmpo'
 
*Jmplog*
 
gen `th_y01_ln_jmp' = (`y01_ln_jmp'/`my01_ln_jmp')*log(`y01_ln_jmp'/`my01_ln_jmp')
reg `th_y01_ln_jmp'
gen `theil_y01_ln_jmp' = _b[_cons]
tempvar theil_ln_jmp
gen `theil_ln_jmp' = `theil_yt' - `theil_y01_ln_jmp'
return scalar theil_ln_jmp = `theil_ln_jmp'


gen `th_y1_ln_jmp' = (`y1_ln_jmp'/`my1_ln_jmp')*log(`y1_ln_jmp'/`my1_ln_jmp')
reg `th_y1_ln_jmp'
gen `theil_y1_ln_jmp' = _b[_cons]
gen `th_y0_ln_jmp' = (`y0_ln_jmp'/`my0_ln_jmp')*log(`y0_ln_jmp'/`my0_ln_jmp')
reg `th_y0_ln_jmp'
gen `theil_y0_ln_jmp' = _b[_cons]
tempvar theil_ln_jmpo
gen `theil_ln_jmpo' = `theil_y1_ln_jmp' - `theil_y0_ln_jmp'
return scalar theil_ln_jmpo = `theil_ln_jmpo'


**********************************************


*** Victor Chernozhukov ,Ivn Fernndez-Val , Blaise Melly ***
tempvar cfm1 
counterfactual `y' strata*, group(T) noboot ql(1) qh(99) qs(1)
matrix define distr = e(distributions)
svmat distr
gen `cfm1' = distr9
drop distr*

 
tempvar my01_cfm att_cfm
egen `my01_cfm' = mean( `cfm1')
gen `att_cfm' = `my_t' - `my01_cfm'
return scalar att_cfm = `att_cfm'

tempvar sdy01_cfm CV_cfm
sum  `cfm1'
gen `sdy01_cfm' = r(sd)
gen `CV_cfm' = `sdy_t'/`my_t' - `sdy01_cfm'/`my01_cfm'
return scalar CV_cfm = `CV_cfm'
 
tempvar iqr_cfm
matrix define y01_cfm_q25 = el(distr,25,9)
matrix define y01_cfm_q75 = el(distr,75,9)
svmat y01_cfm_q25
svmat y01_cfm_q75
gen `iqr_cfm' = (`yt_q75' - `yt_q25') - (y01_cfm_q751 - y01_cfm_q251)
 

return scalar iqr_cfm = `iqr_cfm'
 
   
tempvar  a  gini_cfm gini_y01_cfm
gen `a'= 1 if  `cfm1'~=.
ginicoef  `cfm1' `a'
gen `gini_y01_cfm' = r(gini)
gen `gini_cfm' = `gini_t' -  `gini_y01_cfm'
return scalar gini_cfm = `gini_cfm'

tempvar th_cfm theil_cfm   theil_y01_cfm
gen `th_cfm' = ( `cfm1'/`my01_cfm')*log( `cfm1'/`my01_cfm')
reg `th_cfm'
gen `theil_y01_cfm' = _b[_cons]
gen `theil_cfm' = `theil_yt' - `theil_y01_cfm'
return scalar theil_cfm = `theil_cfm'
 
  

*****************
*outras statisticas *

tempvar nobs countnobs
gen `countnobs' = 1
egen `nobs'= total(`countnobs')
return scalar nobs = `nobs'

tempvar total_negative y01_negative
gen `y01_negative' = 1 if `y01_jmp' <0 | `y01_jmp'==0
egen `total_negative' = total(`y01_negative')
return scalar total_negative = `total_negative'




}
 
end
 
 
 
program define boot1  , eclass
 
args x 
 
ite_planfor `x'
 
 
matrix define   nobs    = r(nobs)  
matrix define   total_negative    = r(total_negative) 
matrix define   theil_cfm = r(theil_cfm)
matrix define   gini_cfm = r(gini_cfm)
matrix define   iqr_cfm= r(iqr_cfm)
matrix define   CV_cfm = r(CV_cfm)
matrix define   att_cfm = r(att_cfm)
matrix define   theil_ln_jmp    = r(theil_ln_jmp)
matrix define   theil_ln_jmpo    = r(theil_ln_jmpo)
matrix define   theil_jmpo    = r(theil_jmpo)
matrix define   theil_jmp    = r(theil_jmp)
matrix define   theil_feasibleo    = r(theil_feasibleo)
matrix define   theil_feasible    = r(theil_feasible)
matrix define   theil_naive    = r(theil_naive)
matrix define   theil_yc    = r(theil_yc)
matrix define   theil_yt    = r(theil_yt)
matrix define   gini_ln_jmpo    = r(gini_ln_jmpo)
matrix define   gini_ln_jmp    = r(gini_ln_jmp)
matrix define   gini_jmpo    = r(gini_jmpo)
matrix define   gini_jmp    = r(gini_jmp)
matrix define   gini_feasibleo    = r(gini_feasibleo)
matrix define   gini_feasible    = r(gini_feasible)
matrix define   gini_naive    = r(gini_naive)
matrix define   gini_c    = r(gini_c)
matrix define   gini_t    = r(gini_t)
matrix define   iqr_ln_jmpo    = r(iqr_ln_jmpo)
matrix define   iqr_ln_jmp    = r(iqr_ln_jmp)
matrix define   iqr_jmpo    = r(iqr_jmpo)
matrix define   iqr_jmp    = r(iqr_jmp)
matrix define   iqr_feasibleo    = r(iqr_feasibleo)
matrix define   iqr_feasible    = r(iqr_feasible)
matrix define   iqr_naive    = r(iqr_naive)
matrix define   iqr_t= r(iqr_t) 
matrix define   iqr_c= r(iqr_c)
matrix define   CV_ln_jmpo    = r(CV_ln_jmpo) 
matrix define   CV_ln_jmp    = r(CV_ln_jmp)
matrix define   CV_jmpo    = r(CV_jmpo)
matrix define   CV_jmp    = r(CV_jmp)
matrix define   CV_feasibleo    = r(CV_feasibleo)
matrix define   CV_feasible    = r(CV_feasible)
matrix define   CV_naiveo    = r(CV_naiveo)
matrix define   CV_naive    = r(CV_naive)
matrix define   CV_co    = r(CV_co)
matrix define   CV_c    = r(CV_c)
matrix define   CV_to    = r(CV_to)
matrix define   CV_t    = r(CV_t)
matrix define   ate_ln_jmp    = r(ate_ln_jmp)
matrix define   att_ln_jmp    = r(att_ln_jmp)
matrix define   ate_jmp    = r(ate_jmp)
matrix define   att_jmp    = r(att_jmp)
matrix define   ate_feasible    = r(ate_feasible)
matrix define   att_feasible    = r(att_feasible)
matrix define   ate_naive = r(ate_naive)
matrix define   att_naive    = r(att_naive)
matrix define   my_ce    = r(my_ce)
matrix define   my_te    = r(my_te)
matrix define   my_c    = r(my_c)
matrix define   my_t    = r(my_t)
matrix define   pscore_max_control    = r(pscore_max_control)
matrix define   pscore_min_control    = r(pscore_min_control)
matrix define   pscore_medio_control    = r(pscore_medio_control)
matrix define   pscore_max_trat    = r(pscore_max_trat)
matrix define   pscore_min_trat    = r(pscore_min_trat)
matrix define   pscore_medio_trat    = r(pscore_medio_trat)
matrix define   pscore_max    = r(pscore_max)
matrix define   pscore_min    = r(pscore_min)
matrix define   pscore_medio    = r(pscore_medio)

matrix define observe = ( nobs \ total_negative \ pscore_max_control   \  pscore_min_control   \  pscore_medio_control   \  pscore_max_trat   \  pscore_min_trat   \  pscore_medio_trat   \  pscore_max   \  pscore_min   \  pscore_medio \  my_c   \  my_t   \  att_ln_jmp   \  att_jmp   \  att_feasible   \  att_naive  \  CV_ln_jmp   \  CV_jmp   \  CV_feasible   \  CV_naive   \  CV_c   \  CV_t  \  iqr_ln_jmp   \  iqr_jmp   \  iqr_feasible   \  iqr_naive \ iqr_t \ iqr_c\ gini_ln_jmp   \  gini_jmp   \  gini_feasible   \  gini_naive   \  gini_c   \  gini_t \  theil_ln_jmp   \  theil_jmp   \  theil_feasible   \  theil_naive   \  theil_yc   \  theil_yt \att_cfm \gini_cfm \  iqr_cfm \CV_cfm \theil_cfm)
matrix rownames observe = nobs  total_negative  pscore_max_control   pscore_min_control   pscore_medio_control   pscore_max_trat   pscore_min_trat   pscore_medio_trat    pscore_max    pscore_min    pscore_medio  my_c   my_t   att_ln_jmp   att_jmp    att_feasible   att_naive   CV_ln_jmp    CV_jmp   CV_feasible   CV_naive   CV_c   CV_t   iqr_ln_jmp   iqr_jmp   iqr_feasible   iqr_naive iqr_t iqr_c gini_ln_jmp    gini_jmp   gini_feasible    gini_naive    gini_c    gini_t  theil_ln_jmp   theil_jmp    theil_feasible    theil_naive   theil_yc    theil_yt att_cfm gini_cfm iqr_cfm  CV_cfm  theil_cfm)
 
end
 
 

program define myboot, rclass

args y 

preserve 

bsample

quietly
{
 
 
***Feasible - Firpo ***
 
 
tempvar p pscore_parametrico w11 w00 sw00 sw01_par w01_par sw11 w1_par sw1_par
tempvar w0_par sw0_par
egen `p'  = mean(T)
logit T strata*
 
predict `pscore_parametrico'

sum `pscore_parametrico'
return scalar pscore_medio = r(mean)
return scalar pscore_min = r(min)
return scalar pscore_max = r(max)

sum `pscore_parametrico' if T==1
return scalar pscore_medio_trat = r(mean)
return scalar pscore_min_trat = r(min)
return scalar pscore_max_trat = r(max)

sum `pscore_parametrico' if T==0
return scalar pscore_medio_control = r(mean)
return scalar pscore_min_control = r(min)
return scalar pscore_max_control = r(max)

 

gen `w11' = T/`p'
egen `sw11'= sum(`w11')
replace `w11' = `w11'/`sw11'
 
gen `w00' = (1-T)/(1-`p')
egen `sw00'= sum(`w00')
replace `w00' = `w00'/`sw00'
 
 
 
gen `w01_par' =  ((1-T)/(1-`pscore_parametrico'))*(`pscore_parametrico'/`p')
egen `sw01_par' = sum(`w01_par')
replace `w01_par' =  `w01_par'/`sw01_par'
 
 
gen `w1_par' =  (T/`pscore_parametrico')
egen `sw1_par' = sum(`w1_par')
replace `w1_par' =  `w1_par'/`sw1_par'

gen `w0_par' =  ((1-T)/(1-`pscore_parametrico'))
egen `sw0_par' = sum(`w0_par')
replace `w0_par' = `w0_par'/`sw0_par' 
 
**********************************************************************************
*** Counterfactual : Juhn, Murphy and Pierce ***
 
tempvar xtbetac sigma_c sigma_t sigmac2 y01_jmp erro_t lny stbetac2 sigma_c2 sigma_t2  erro_t2 lny_01jmp y01_ln_jmp xtbetac2 xtbetac3 sigma_c3 erro_t3 sigma_t3 lny_01jmp_q y01_ln_jmp_q
 
*** Counterfactual : Juhn, Murphy and Pierce *** (quadratico em X, variavel dep: y)
 
 
reg `y' strata*  if T==0
predict `xtbetac' if T==1
 
gen `sigma_c' = e(rss)/e(df_r)
 
reg `y' strata* if T==1
predict `erro_t' , residuals 
gen `sigma_t' = e(rss)/e(df_r)
 
 
gen `y01_jmp' = `xtbetac' + sqrt(`sigma_c'/`sigma_t')*`erro_t' 


tempvar xtbetac1 sigma_c_1 erro_to sigma_to y1_jmp xtbetac0 sigma_c_0 y0_jmp termc1 termc0

reg `y' strata*  if T==1
predict `xtbetac1' 
 
gen `sigma_c_1' = e(rss)/e(df_r)
 
reg `y' strata* 
predict `erro_to' , residuals 
gen `sigma_to' = e(rss)/e(df_r)

gen  `termc1' = sqrt(`sigma_c_1'/`sigma_to')*`erro_to'
gen `y1_jmp' = `xtbetac1' +  `termc1'   


reg `y' strata*  if T==0
predict `xtbetac0' 
 
gen `sigma_c_0' = e(rss)/e(df_r) 

gen  `termc0' = sqrt(`sigma_c_0'/`sigma_to')*`erro_to' 
gen `y0_jmp' = `xtbetac0' +  `termc0'
 
*** Counterfactual : Juhn, Murphy and Pierce *** (quadratico em X, variavel dep: ln(y)) 
 
gen `lny' = log(`y')
 
reg `lny' strata* if T==0
predict `xtbetac2' if T==1
 
gen `sigma_c2' = e(rss)/e(df_r)
 
reg `lny' strata*  if T==1
predict `erro_t2' , residuals 
gen `sigma_t2' = e(rss)/e(df_r)
 
gen `lny_01jmp' = `xtbetac2' + sqrt(`sigma_c2'/`sigma_t2')*`erro_t2' 
gen `y01_ln_jmp' = exp(`lny_01jmp') 
 
 
tempvar  xtbetac21 sigma_c21 xtbetac20 sigma_c20 erro_t20  sigma_t20 lny_1jmp y1_ln_jmp lny_0jmp y0_ln_jmp
 
reg `lny' strata* if T==1
predict `xtbetac21' 
 
gen `sigma_c21' = e(rss)/e(df_r)
 
reg `lny' strata* if T==0
predict `xtbetac20' 
 
gen `sigma_c20' = e(rss)/e(df_r)
 
reg `lny' strata* 
predict `erro_t20' , residuals 
gen `sigma_t20' = e(rss)/e(df_r)

gen `lny_1jmp' = `xtbetac21' + sqrt(`sigma_c21'/`sigma_t20')*`erro_t20' 
gen `y1_ln_jmp' = exp(`lny_1jmp')  

 
gen `lny_0jmp' = `xtbetac20' + sqrt(`sigma_c20'/`sigma_t20')*`erro_t20' 
gen `y0_ln_jmp' = exp(`lny_0jmp')  
************************************************************************************
 
 
 
************************************************************************************
 
 
 
* Gerando as estatisticas de interesse *
 

*Average*
 
tempvar my1 my0  my_t my_c my01_feasible my01_jmp my01_ln_jmp my01_ln_jmp_q
 
 
 
* Naive *
 
reg `y' [w=`w11']
gen `my_t' = _b[_cons]
return scalar my_t = `my_t'
reg `y' [w=`w00']
gen `my_c' = _b[_cons]
return scalar my_c = `my_c'
tempvar att_naive
gen `att_naive' = `my_t' - `my_c'
return scalar att_naive = `att_naive'
 
 
tempvar my_to my_co 
reg `y' [w=`w11']
gen `my_to' = _b[_cons]
return scalar my_to = `my_to'
reg `y' [w=`w00']
gen `my_co' = _b[_cons]
return scalar my_co = `my_co'
tempvar ate_naive 
gen `ate_naive' = `my_to' - `my_co'
return scalar ate_naive = `ate_naive' 
 
*Firpo*
 
tempvar att_feasible
reg `y' [w=`w01_par']
gen `my01_feasible' = _b[_cons]
gen `att_feasible' = `my_t' - `my01_feasible'
return scalar att_feasible = `att_feasible'

tempvar ate_feasible my1_feasible  my0_feasible
reg `y' [w=`w1_par']
gen `my1_feasible' = _b[_cons]
reg `y' [w=`w0_par']
gen `my0_feasible' = _b[_cons]
gen `ate_feasible' = `my1_feasible' - `my0_feasible'
return scalar ate_feasible = `ate_feasible'
 
 
*JMP_y*
egen `my01_jmp' = mean(`y01_jmp')
tempvar att_jmp
gen `att_jmp' = `my_t' -  `my01_jmp'
return scalar att_jmp = `att_jmp'
 
tempvar my1_jmp my0_jmp
egen `my1_jmp' = mean(`y1_jmp')
egen `my0_jmp' = mean(`y0_jmp')
tempvar ate_jmp 
gen `ate_jmp' = `my1_jmp' -  `my0_jmp'
return scalar ate_jmp = `ate_jmp'  

*JMP_lny*
egen `my01_ln_jmp' = mean(`y01_ln_jmp')
tempvar att_ln_jmp
gen `att_ln_jmp' = `my_t' - `my01_ln_jmp'
return scalar att_ln_jmp  = `att_ln_jmp'
 
 
tempvar my1_ln_jmp my0_ln_jmp
egen `my1_ln_jmp' = mean(`y1_ln_jmp') 
egen `my0_ln_jmp' = mean(`y0_ln_jmp')
tempvar ate_ln_jmp 
gen `ate_ln_jmp' = `my1_ln_jmp' - `my0_ln_jmp'
return scalar ate_ln_jmp  = `ate_ln_jmp'
 
 
*Coeficiente de Variacao *
 
tempvar sdy1 sdy0 sdy_t sdy_c sdy01_feasible sdy01_jmp sdy01_ln_jmp sdy01_ln_jmp_q
 
 
 
*Naive*
 
sum `y' [w=`w11']
gen  `sdy_t' = r(sd)
sum `y' [w=`w00']
gen `sdy_c' = r(sd)
tempvar CV_t CV_c
gen  `CV_t' = `sdy_t'/`my_t'
gen  `CV_c' = `sdy_c'/`my_c'
return scalar CV_t = `CV_t'
return scalar CV_c = `CV_c'
tempvar CV_naive
gen `CV_naive'  = `sdy_t'/`my_t' - `sdy_c'/`my_c'
return scalar CV_naive = `CV_naive'

tempvar  sdy_to sdy_co
sum `y' [w=`w11']
gen  `sdy_to' = r(sd)
sum `y' [w=`w00']
gen `sdy_co' = r(sd)
tempvar CV_naiveo CV_to CV_co 
gen `CV_naiveo'  = `sdy_to'/`my_to' - `sdy_co'/`my_co'
gen  `CV_to' = `sdy_to'/`my_to'
gen  `CV_co' = `sdy_co'/`my_co'
return scalar CV_to = `CV_to'
return scalar CV_co = `CV_co'
return scalar CV_naiveo = `CV_naiveo' 
 
*Feasible-Firpo*
 
summ `y'[w=`w01_par']
gen `sdy01_feasible' = r(sd)
tempvar CV_feasible
gen `CV_feasible' = `sdy_t'/`my_t'  -  `sdy01_feasible'/`my01_feasible'
return scalar CV_feasible  = `CV_feasible'
 
tempvar  sdy0_feasible sdy1_feasible
summ `y' [w=`w0_par']
gen `sdy0_feasible' = r(sd)
summ `y' [w=`w1_par']
gen `sdy1_feasible' = r(sd)
tempvar CV_feasibleo
gen `CV_feasibleo' = `sdy1_feasible'/`my1_feasible'  -  `sdy0_feasible'/`my0_feasible'
return scalar CV_feasibleo  = `CV_feasibleo'
 
*JMP*
 
egen `sdy01_jmp' = sd(`y01_jmp')
tempvar CV_jmp
gen `CV_jmp' = `sdy_t'/`my_t' - `sdy01_jmp'/`my01_jmp'
return scalar CV_jmp = `CV_jmp'


tempvar sdy1_jmp sdy0_jmp
egen `sdy1_jmp' = sd(`y1_jmp') 
egen `sdy0_jmp' = sd(`y0_jmp')
tempvar CV_jmpo
gen `CV_jmpo' = `sdy1_jmp'/`my1_jmp' - `sdy0_jmp'/`my0_jmp'
return scalar CV_jmpo = `CV_jmpo' 
 
* JMP_lny*
 
egen `sdy01_ln_jmp' = sd(`y01_ln_jmp')
tempvar CV_ln_jmp
gen `CV_ln_jmp' = `sdy_t'/`my_t' - `sdy01_ln_jmp'/`my01_ln_jmp'
return scalar CV_ln_jmp = `CV_ln_jmp'
 

tempvar sdy1_ln_jmp sdy0_ln_jmp
egen `sdy1_ln_jmp' = sd(`y1_ln_jmp') 
egen `sdy0_ln_jmp' = sd(`y0_ln_jmp')
tempvar CV_ln_jmpo
gen `CV_ln_jmpo' = `sdy1_ln_jmp'/`my1_ln_jmp' - `sdy0_ln_jmp'/`my0_ln_jmp'
return scalar CV_ln_jmpo = `CV_ln_jmpo' 
 
 
 
*Interquartile Range *
 
 
tempvar y1_q75 y1_q25 y0_q75 y0_q25 yt_q75 yt_q25 yc_q75 yc_q25
tempvar  y01_q75feasible  y01_q25feasible y01_q75jmp y01_q25jmp  y01_q75_ln_jmp y01_q25_ln_jmp  y01_q75_ln_jmp_q y01_q25_ln_jmp_q

 
* Naive *
tempvar w11a w00a
gen `w11a'=round(`w11'*1000000)
gen `w00a'=round(`w00'*1000000) 
quietly qreg `y'[w=`w11a'] , quantile (.75)
gen `yt_q75' = e(q_v)
quietly qreg `y'[w=`w11a'] , quantile (.25)
gen `yt_q25' = e(q_v)
tempvar iqr_t iqr_c
gen `iqr_t'  = (`yt_q75' - `yt_q25' )
return scalar iqr_t  =`iqr_t'
quietly qreg `y'[w=`w00a'] , quantile (.75)
gen `yc_q75' = e(q_v)
quietly  qreg `y'[w=`w00a'] , quantile (.25)
gen `yc_q25' = e(q_v)
gen `iqr_c'  = (`yc_q75' - `yc_q25' )
return scalar iqr_c  =`iqr_c'
tempvar iqr_naive
gen `iqr_naive' = (`yt_q75' - `yt_q25' ) - (`yc_q75' - `yc_q25' )
return scalar iqr_naive = `iqr_naive'


* Feasible-Firpo *
tempvar w01_para
gen `w01_para'=round(`w01_par'*1000000)
quietly  qreg `y'[w=`w01_para'] , quantile (.75)
gen `y01_q75feasible' = e(q_v)
quietly  qreg `y'[w=`w01_para'], quantile (.25)
gen `y01_q25feasible' = e(q_v)
tempvar iqr_feasible
gen  `iqr_feasible' = (`yt_q75' - `yt_q25' ) - (`y01_q75feasible' - `y01_q25feasible')
return scalar iqr_feasible  = `iqr_feasible'


tempvar w1_para w0_para y1_q75feasible y1_q25feasible y0_q75feasible y0_q25feasible
gen `w1_para'=round(`w1_par'*1000000)
quietly  qreg `y' [w=`w1_para'] , quantile (.75)
gen `y1_q75feasible' = e(q_v)
quietly  qreg `y' [w=`w1_para'], quantile (.25)
gen `y1_q25feasible' = e(q_v)
gen `w0_para'=round(`w0_par'*1000000)
quietly  qreg `y' [w=`w0_para'] , quantile (.75)
gen `y0_q75feasible' = e(q_v)
quietly  qreg `y' [w=`w0_para'], quantile (.25)
gen `y0_q25feasible' = e(q_v)
tempvar iqr_feasibleo
gen  `iqr_feasibleo' = (`y1_q75feasible' - `y1_q25feasible') - (`y0_q75feasible' - `y0_q25feasible')
return scalar iqr_feasibleo  = `iqr_feasibleo'
 
* JMP *
 
quietly  qreg `y01_jmp' , quantile(.75)
gen `y01_q75jmp' = e(q_v)
quietly  qreg `y01_jmp', quantile (.25)
gen `y01_q25jmp' = e(q_v)
tempvar iqr_jmp
gen `iqr_jmp' = ( `yt_q75' - `yt_q25') - (`y01_q75jmp' - `y01_q25jmp')
return scalar iqr_jmp = `iqr_jmp'

tempvar y1_q75jmp y0_q75jmp y1_q25jmp y0_q25jmp
quietly  qreg `y1_jmp' , quantile(.75)
gen `y1_q75jmp' = e(q_v)
quietly  qreg `y1_jmp', quantile (.25)
gen `y1_q25jmp' = e(q_v)
quietly qreg `y0_jmp' , quantile(.75)
gen `y0_q75jmp' = e(q_v)
quietly  qreg `y0_jmp', quantile (.25)
gen `y0_q25jmp' = e(q_v)
tempvar iqr_jmpo
gen `iqr_jmpo' = (`y1_q75jmp' - `y1_q25jmp') - (`y0_q75jmp' - `y0_q25jmp')
return scalar iqr_jmpo = `iqr_jmpo' 


 
*JMP_lny *
 
quietly  qreg `y01_ln_jmp' , quantile (.75)
gen `y01_q75_ln_jmp' = e(q_v)
quietly qreg `y01_ln_jmp' , quantile (.25)
gen `y01_q25_ln_jmp' = e(q_v)
tempvar iqr_ln_jmp
gen `iqr_ln_jmp'= (`yt_q75' - `yt_q25') - (`y01_q75_ln_jmp' - `y01_q25_ln_jmp')
return scalar iqr_ln_jmp = `iqr_ln_jmp'
 
tempvar  y0_q75_ln_jmp y1_q75_ln_jmp y0_q25_ln_jmp y1_q25_ln_jmp
quietly  qreg `y1_ln_jmp' , quantile (.75)
gen `y1_q75_ln_jmp' = e(q_v)
quietly qreg `y1_ln_jmp' , quantile (.25)
gen `y1_q25_ln_jmp' = e(q_v)
quietly  qreg `y0_ln_jmp' , quantile (.75)
gen `y0_q75_ln_jmp' = e(q_v)
quietly  qreg `y0_ln_jmp' , quantile (.25)
gen `y0_q25_ln_jmp' = e(q_v)
tempvar iqr_ln_jmpo
gen `iqr_ln_jmpo'= (`y1_q75_ln_jmp' - `y1_q25_ln_jmp') - (`y0_q75_ln_jmp' - `y0_q25_ln_jmp')
return scalar iqr_ln_jmpo = `iqr_ln_jmpo'
  
 
*Gini* 
tempvar gini_y1 gini_y0  gini_t gini_c gini_y01feasible
 
**Naive **
ginicoef `y' `w11'
gen `gini_t' = r(gini)
ginicoef `y' `w00'
gen `gini_c' = r(gini)
return scalar gini_t = `gini_t'
return scalar gini_c = `gini_c'
tempvar gini_naive
gen `gini_naive' =  `gini_t' - `gini_c'

return scalar gini_naive = `gini_naive'


 
* Feasible - Firpo *
 
ginicoef `y' `w01_par'
gen `gini_y01feasible' = r(gini)
tempvar gini_feasible
gen `gini_feasible' = `gini_t' - `gini_y01feasible'
return scalar gini_feasible = `gini_feasible'

tempvar gini_y1feasible gini_y0feasible 
ginicoef `y' `w1_par'
gen `gini_y1feasible' = r(gini)
ginicoef `y' `w0_par'
gen `gini_y0feasible' = r(gini)
tempvar gini_feasibleo
gen `gini_feasibleo' = `gini_y1feasible' - `gini_y0feasible'
return scalar gini_feasibleo = `gini_feasibleo'

 
* JMP *
tempvar gini_y01jmp gini_y01_ln_jmp  y01_jmp_positive
 
gen `y01_jmp_positive' = `y01_jmp' if `y01_jmp'>0
ginicoef `y01_jmp_positive' `w11'
gen `gini_y01jmp' = r(gini)
tempvar gini_jmp
gen `gini_jmp' = `gini_t' -  `gini_y01jmp'
return scalar gini_jmp = `gini_jmp'


tempvar y1_jmp_positive y0_jmp_positive total_negative1 total_negative0
gen `y1_jmp_positive' = `y1_jmp' if `y1_jmp'>0
gen `total_negative1' = missing(`y1_jmp_positive')
replace `total_negative1' =sum(`total_negative1')
return scalar total_negative1 = `total_negative1'

gen `y0_jmp_positive' = `y0_jmp' if `y0_jmp'>0
gen `total_negative0' = missing(`y0_jmp_positive')
replace `total_negative0' =sum(`total_negative0')
return scalar total_negative0 = `total_negative0'

tempvar gini_y1jmp gini_y0jmp wg
gen  `wg'=1
ginicoef `y1_jmp_positive'  `wg'
gen `gini_y1jmp' = r(gini)
ginicoef `y0_jmp_positive' `wg'
gen `gini_y0jmp' = r(gini)
tempvar gini_jmpo 
gen `gini_jmpo' = `gini_y1jmp' -  `gini_y0jmp'
return scalar gini_jmpo = `gini_jmpo' 

 
*JMP_lny*
 
ginicoef `y01_ln_jmp'  `w11'
gen `gini_y01_ln_jmp' = r(gini)
tempvar gini_ln_jmp
gen `gini_ln_jmp'  = `gini_t' - `gini_y01_ln_jmp'
return scalar gini_ln_jmp = `gini_ln_jmp'
 
 
tempvar  gini_y1_ln_jmp gini_y0_ln_jmp
ginicoef `y1_ln_jmp'  `wg'
gen `gini_y1_ln_jmp' = r(gini)
ginicoef `y0_ln_jmp'  `wg'
gen `gini_y0_ln_jmp' = r(gini)
tempvar gini_ln_jmpo  
gen `gini_ln_jmpo'  = `gini_y1_ln_jmp' - `gini_y0_ln_jmp'
return scalar gini_ln_jmpo = `gini_ln_jmpo' 
 
*Theil Index *
tempvar th_y1 th_y0 th_yt th_yc th_y01feasible th_y01jmp ty_y01_ln_jmp 
tempvar theil_y1 theil_yt theil_y0 theil_yc theil_y01feasible
 
 
 
*Naive*
gen `th_yt' = (`y'/`my_t')*log(`y'/`my_t')
reg `th_yt'  [w=`w11']
gen `theil_yt' = _b[_cons]
gen `th_yc' = (`y'/`my_c')*log(`y'/`my_c')
reg `th_yc'  [w=`w00']
gen `theil_yc' = _b[_cons]
tempvar theil_naive 
return scalar theil_yt = `theil_yt'
return scalar theil_yc = `theil_yc'

gen `theil_naive' = `theil_yt' - `theil_yc'
return scalar theil_naive = `theil_naive'
 
 
*Firpo-Feasible *
tempvar theil_feasible th_y01jmp th_y01_ln_jmp theil_y01jmp theil_ln_jmp theil_y01_ln_jmp
 
 
gen `th_y01feasible' = (`y'/`my01_feasible')*(log(`y'/`my01_feasible'))
reg `th_y01feasible'  [w=`w01_par']
gen `theil_y01feasible' = _b[_cons]
gen `theil_feasible' = `theil_yt' - `theil_y01feasible'
return scalar theil_feasible = `theil_feasible'
 
 
tempvar theil_feasibleo th_y0feasible theil_y0feasible th_y1feasible theil_y1feasible
gen `th_y0feasible' = (`y'/`my0_feasible' )*(log(`y'/`my0_feasible'))
reg `th_y0feasible'  [w=`w0_par']
gen `theil_y0feasible' = _b[_cons]

gen `th_y1feasible' = (`y'/`my1_feasible' )*(log(`y'/`my1_feasible'))
reg `th_y1feasible'  [w=`w1_par']
gen `theil_y1feasible' = _b[_cons]
gen `theil_feasibleo' = `theil_y1feasible' - `theil_y0feasible'
return scalar theil_feasibleo = `theil_feasibleo'
 
*Jmp *
 
tempvar my01_jmp_positive
egen `my01_jmp_positive' = mean(`y01_jmp_positive')
gen `th_y01jmp' = (`y01_jmp_positive'/`my01_jmp_positive')*log(`y01_jmp_positive'/`my01_jmp_positive')
reg `th_y01jmp'
gen `theil_y01jmp'= _b[_cons]
tempvar theil_jmp
gen `theil_jmp' = `theil_yt' - `theil_y01jmp'
return scalar theil_jmp = `theil_jmp'

tempvar my1_jmp_positive th_y1jmp theil_y1jmp th_y1_ln_jmp theil_y1_ln_jmp my0_jmp_positive th_y0jmp theil_y0jmp th_y0_ln_jmp theil_y0_ln_jmp 
egen `my0_jmp_positive' = mean(`y0_jmp_positive')
gen `th_y0jmp' = (`y0_jmp_positive'/`my0_jmp_positive')*log(`y0_jmp_positive'/`my0_jmp_positive')
reg `th_y0jmp'
gen `theil_y0jmp'= _b[_cons]
egen `my1_jmp_positive' = mean(`y1_jmp_positive')
gen `th_y1jmp' = (`y1_jmp_positive'/`my1_jmp_positive')*log(`y1_jmp_positive'/`my1_jmp_positive')
reg `th_y1jmp'
gen `theil_y1jmp'= _b[_cons]
tempvar theil_jmpo
gen `theil_jmpo' = `theil_y1jmp' - `theil_y0jmp'
return scalar theil_jmpo = `theil_jmpo'

 
*Jmplog*
 
gen `th_y01_ln_jmp' = (`y01_ln_jmp'/`my01_ln_jmp')*log(`y01_ln_jmp'/`my01_ln_jmp')
reg `th_y01_ln_jmp'
gen `theil_y01_ln_jmp' = _b[_cons]
tempvar theil_ln_jmp
gen `theil_ln_jmp' = `theil_yt' - `theil_y01_ln_jmp'
return scalar theil_ln_jmp = `theil_ln_jmp'

gen `th_y1_ln_jmp' = (`y1_ln_jmp'/`my1_ln_jmp')*log(`y1_ln_jmp'/`my1_ln_jmp')
reg `th_y1_ln_jmp'
gen `theil_y1_ln_jmp' = _b[_cons]
gen `th_y0_ln_jmp' = (`y0_ln_jmp'/`my0_ln_jmp')*log(`y0_ln_jmp'/`my0_ln_jmp')
reg `th_y0_ln_jmp'
gen `theil_y0_ln_jmp' = _b[_cons]
tempvar theil_ln_jmpo
gen `theil_ln_jmpo' = `theil_y1_ln_jmp' - `theil_y0_ln_jmp'
return scalar theil_ln_jmpo = `theil_ln_jmpo'






 ***************************


*** Victor Chernozhukov ,Ivn Fernndez-Val , Blaise Melly ***
counterfactual `y' strata* , group(T) noboot  ql(1) qh(99) qs(1)
matrix define distr = e(distributions)
svmat distr
gen cfm1 = distr9
drop distr*

 
tempvar my01_cfm att_cfm
egen `my01_cfm' = mean(cfm1)
gen `att_cfm' = `my_t' - `my01_cfm'
return scalar att_cfm = `att_cfm'

tempvar sdy01_cfm CV_cfm
sum cfm1
gen `sdy01_cfm' = r(sd)
gen `CV_cfm' = `sdy_t'/`my_t' - `sdy01_cfm'/`my01_cfm'
return scalar CV_cfm = `CV_cfm'
 

tempvar iqr_cfm
matrix define y01_cfm_q25 = el(distr,25,9)
matrix define y01_cfm_q75 = el(distr,75,9)
tempvar y01_cfm_q251 y01_cfm_q751 
gen `y01_cfm_q251' = trace(y01_cfm_q25)
gen `y01_cfm_q751' = trace(y01_cfm_q75)
gen `iqr_cfm' = (`yt_q75' - `yt_q25') - (`y01_cfm_q751' - `y01_cfm_q251')



return scalar iqr_cfm = `iqr_cfm'
 
  
tempvar  a  gini_cfm gini_y01_cfm
gen `a'= 1 if cfm1~=.
ginicoef cfm1 `a'
gen `gini_y01_cfm' = r(gini)
gen `gini_cfm' = `gini_t' -  `gini_y01_cfm'
return scalar gini_cfm = `gini_cfm'

tempvar th_cfm theil_cfm   theil_y01_cfm
gen `th_cfm' = (cfm1/`my01_cfm')*log(cfm1/`my01_cfm')
reg `th_cfm'
gen `theil_y01_cfm' = _b[_cons]
gen `theil_cfm' = `theil_yt' - `theil_y01_cfm'
return scalar theil_cfm = `theil_cfm'



*****************
*outras statisticas *

tempvar nobs countnobs
gen `countnobs' = 1
egen `nobs'= total(`countnobs')
return scalar nobs = `nobs'


tempvar total_negative y01_negative
gen `y01_negative' = 1 if `y01_jmp' <0 | `y01_jmp'==0
egen `total_negative' = total(`y01_negative')
return scalar total_negative = `total_negative'




}


restore
end



 
 
